nrf-pac

Crates

git

Versions

nrf5340-app

Flavors

AoApbFiltering

Struct AoApbFiltering 

#[repr(transparent)]
pub struct AoApbFiltering(pub u32);
This register holds the AO_APB_FILTERING configuration.

Tuple Fields

0: u32

Implementations

Source

impl AoApbFiltering

pub const fn only_sec_access_allowed(&self) -> bool

When this FW controlled field is set, the APB slave accepts only secure accesses

pub const fn set_only_sec_access_allowed(&mut self, val: bool)

When this FW controlled field is set, the APB slave accepts only secure accesses

pub const fn only_sec_access_allowed_lock(&self) -> bool

When this FW controlled field is set, the ONLY_SEC_ACCESS_ALLOWED field cannot be modified until the next PoR

pub const fn set_only_sec_access_allowed_lock(&mut self, val: bool)

When this FW controlled field is set, the ONLY_SEC_ACCESS_ALLOWED field cannot be modified until the next PoR

pub const fn only_priv_access_allowed(&self) -> bool

When this FW controlled field is set, the APB slave accepts only privileged accesses

pub const fn set_only_priv_access_allowed(&mut self, val: bool)

When this FW controlled field is set, the APB slave accepts only privileged accesses

pub const fn only_priv_access_allowed_lock(&self) -> bool

When this FW controlled field is set, the APBC_ONLY_PRIV_ACCESS_ALLOWED field cannot be modified until the next PoR

pub const fn set_only_priv_access_allowed_lock(&mut self, val: bool)

When this FW controlled field is set, the APBC_ONLY_PRIV_ACCESS_ALLOWED field cannot be modified until the next PoR